@@ -33,28 +33,30 @@ def get_mnemonic(p, v, is_input):
     if key in _DB:
         return _DB[key]
 
-    params = v.split(";") 
-    length = len(params)
-
-    if length > 0:
-        key = "%s ESC %s%s<ST>" % (direction, p, params[0])
+    if v[0].isalpha():
+        key = "%s ESC %s%s<ST>" % (direction, p, v[0])
         if key in _DB:
             return _DB[key]
+    else:
+        params = v.split(";") 
+        length = len(params)
 
-    if length > 1:
-        key = "%s ESC %s%s;%s<ST>" % (direction, p, params[0], params[1])
-        if key in _DB:
-            return _DB[key]
-
-    if length > 2:
-        key = "%s ESC %s%s;%s;%s<ST>" % (direction, p, params[0], params[1], params[2])
-        if key in _DB:
-            return _DB[key]
-
-    if length > 3:
-        key = "%s ESC %s%s;%s;%s;%s<ST>" % (direction, p, params[0], params[1], params[2], params[3])
-        if key in _DB:
-            return _DB[key]
+        if length > 3:
+            key = "%s ESC %s%s;%s;%s;%s<ST>" % (direction, p, params[0], params[1], params[2], params[3])
+            if key in _DB:
+                return _DB[key]
+        if length > 2:
+            key = "%s ESC %s%s;%s;%s<ST>" % (direction, p, params[0], params[1], params[2])
+            if key in _DB:
+                return _DB[key]
+        if length > 1:
+            key = "%s ESC %s%s;%s<ST>" % (direction, p, params[0], params[1])
+            if key in _DB:
+                return _DB[key]
+        if length > 0:
+            key = "%s ESC %s%s<ST>" % (direction, p, params[0])
+            if key in _DB:
+                return _DB[key]
 
     key = "%s ESC %s<ST>" % (direction, p)
     if key in _DB:
@@ -62,13 +64,13 @@ def get_mnemonic(p, v, is_input):
 
     return '[ESC ' + p + ']'
 
-def format(prefix, value, is_input):
+def format(prefix, value, is_input, tracer, controller):
     """
       >>> _create_mock_db() 
-      >>> format(ord("]"), map(ord, "abcde"), False).replace("\x1b", "\\x1b")
+      >>> format(ord("]"), map(ord, "abcde"), False, None, None).replace("\x1b", "\\x1b")
       u'\\x1b[0;1;37;44mESC ] \\x1b[0;1;35mabcde \\x1b[37;44mST\\x1b[0;1;36m  OSC / operating system command'
 
-      >>> format(ord("Q"), map(ord, "cdefg"), False)
+      >>> format(ord("Q"), map(ord, "cdefg"), False, None, None)
       u'\\x1b[0;1;37;44mESC Q \\x1b[0;1;35mcdefg \\x1b[37;44mST\\x1b[0;1;36m  [ESC Q]'
     """
 
@@ -79,6 +81,9 @@ def format(prefix, value, is_input):
     p = chr(prefix)
 
     mnemonic = get_mnemonic(p, v, is_input)
+    if mnemonic[0] == "!":
+        return eval(mnemonic[1:])
+
     result = "\x1b[0;1;37;44mESC %s \x1b[0;1;35m%s \x1b[37;44mST\x1b[0;1;36m  %s" % (p, v, mnemonic)
     return result 
 
