@@ -23,11 +23,10 @@ import constant
 
 class OutputHandler(tff.DefaultHandler):
 
-    def __init__(self, actions, tracer):
+    def __init__(self, controller, tracer):
         self.__super = super(tff.DefaultHandler, self)
-        self.__tracer = tracer
-        self.__super.__init__()
-        self.__actions = actions
+        self._tracer = tracer
+        self._controller = controller
 
     def handle_csi(self, context, parameter, intermediate, final):
         def action():
@@ -38,10 +37,10 @@ class OutputHandler(tff.DefaultHandler):
             for c in intermediate:
                 context.put(c)
             context.put(final)
-            self.__tracer.set_output()
-            self.__tracer.handle_csi(context, parameter, intermediate, final)
+            self._tracer.set_output()
+            self._tracer.handle_csi(context, parameter, intermediate, final)
             return constant.SEQ_TYPE_CSI
-        self.__actions.append(action)
+        self._controller.append(action)
         return True # handled
 
     def handle_esc(self, context, intermediate, final):
@@ -50,10 +49,10 @@ class OutputHandler(tff.DefaultHandler):
             for c in intermediate:
                 context.put(c)
             context.put(final)
-            self.__tracer.set_output()
-            self.__tracer.handle_esc(context, intermediate, final)
+            self._tracer.set_output()
+            self._tracer.handle_esc(context, intermediate, final)
             return constant.SEQ_TYPE_ESC
-        self.__actions.append(action)
+        self._controller.append(action)
         return True # handled
 
     def handle_ss2(self, context, final):
@@ -61,10 +60,10 @@ class OutputHandler(tff.DefaultHandler):
             self.put(0x1b) # ESC
             self.put(0x4e) # N
             self.put(final)
-            self.__tracer.set_output()
-            self.__tracer.handle_ss2(context, final)
+            self._tracer.set_output()
+            self._tracer.handle_ss2(context, final)
             return constant.SEQ_TYPE_SS2
-        self.__actions.append(action)
+        self._controller.append(action)
         return True # handled
 
     def handle_ss3(self, context, final):
@@ -72,10 +71,10 @@ class OutputHandler(tff.DefaultHandler):
             self.put(0x1b) # ESC
             self.put(0x4f) # O
             self.put(final)
-            self.__tracer.set_output()
-            self.__tracer.handle_ss3(context, final)
+            self._tracer.set_output()
+            self._tracer.handle_ss3(context, final)
             return constant.SEQ_TYPE_SS3
-        self.__actions.append(action)
+        self._controller.append(action)
         return True # handled
 
     def handle_control_string(self, context, prefix, value):
@@ -86,37 +85,37 @@ class OutputHandler(tff.DefaultHandler):
                 context.put(c)
             context.put(0x1b) # ESC
             context.put(0x5c) # \
-            self.__tracer.set_output()
-            self.__tracer.handle_control_string(context, prefix, value)
+            self._tracer.set_output()
+            self._tracer.handle_control_string(context, prefix, value)
             return constant.SEQ_TYPE_STR
-        self.__actions.append(action)
+        self._controller.append(action)
         return True
 
     def handle_char(self, context, final):
         def action():
             context.put(final)
-            self.__tracer.set_output()
-            self.__tracer.handle_char(context, final)
+            self._tracer.set_output()
+            self._tracer.handle_char(context, final)
             return constant.SEQ_TYPE_CHAR
-        self.__actions.append(action)
+        self._controller.append(action)
         return True # handled
 
     def handle_invalid(self, context, seq):
         def action():
             for c in seq:
                 context.put(c)
-            self.__tracer.set_output()
-            self.__tracer.handle_invalid(context, seq)
+            self._tracer.set_output()
+            self._tracer.handle_invalid(context, seq)
             return constant.SEQ_TYPE_CHAR
-        self.__actions.append(action)
+        self._controller.append(action)
         return True # handled
 
     def handle_resize(self, context, row, col):
-        self.__tracer.handle_resize(context, row, col)
+        self._tracer.handle_resize(context, row, col)
 
     def handle_draw(self, context):
-        self.__actions.tick()
-        self.__tracer.handle_draw(context)
+        self._controller.tick()
+        self._tracer.handle_draw(context)
 
 if __name__ == "__main__":
    import doctest
