@@ -112,7 +112,7 @@ _SEQDB = {
     '< CSI ?65;1;2;3;4;6;8;9;18;21;22;29;42;44c':
     'DA1 Response: VT500 family (could be RLogin)',
     '< CSI >c'           : 'DA2 Response',
-    '< CSI >0;[2]c'      : 'DA2 Response: VT100, Pv=%d, keyboard type=%d',
+    '< CSI >0;[2]c'      : 'DA2 Response: VT100, Pv=%s, keyboard type=%s',
     '< CSI >0;95;c'      : 'DA2 Response: xterm pattch#95 (could be iTerm/iTerm2)',
     '< CSI >0;95;0c'     : 'DA2 Response: xterm pattch#95 (could be tmux/)',
     '< CSI >0;95;1c'     : 'DA2 Response: xterm pattch#95 (could be avaliable mouse)',
@@ -128,19 +128,19 @@ _SEQDB = {
     '< CSI >0;277;0c'    : 'DA2 Response: VT100 (could be xterm patch#277 or tanasinn)',
     '< CSI >0;278;0c'    : 'DA2 Response: VT100 (could be xterm patch#278)',
     '< CSI >0;279;0c'    : 'DA2 Response: VT100 (could be xterm patch#279)',
-    '< CSI >1;[2]c'      : 'DA2 Response: VT220, Pv=%d, keyboard type=%d',
+    '< CSI >1;[2]c'      : 'DA2 Response: VT220, Pv=%s, keyboard type=%s',
     '< CSI >1;10;0c'     : 'DA2 Response: VT220 (could be mosh/WizConsole VT200 mode)',
     '< CSI >1;96;0c'     : 'DA2 Response: VT220 (could be xterm pattch#96, mlterm)',
     '< CSI >1;2403;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
     '< CSI >1;2802;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
-    '< CSI >2;[2]c'      : 'DA2 Response: VT240, Pv=%d, keyboard type=%d',
-    '< CSI >18;[2]c'     : 'DA2 Response: VT330, Pv=%d, keyboard type=%d',
-    '< CSI >19;[2]c'     : 'DA2 Response: VT340, Pv=%d, keyboard type=%d',
-    '< CSI >19;[2]c'     : 'DA2 Response: VT340, Pv=%d, keyboard type=%d',
-    '< CSI >24;[2]c'     : 'DA2 Response: VT320, Pv=%d, keyboard type=%d',
-    '< CSI >32;[2]c'     : 'DA2 Response: VT382, Pv=%d, keyboard type=%d',
+    '< CSI >2;[2]c'      : 'DA2 Response: VT240, Pv=%s, keyboard type=%s',
+    '< CSI >18;[2]c'     : 'DA2 Response: VT330, Pv=%s, keyboard type=%s',
+    '< CSI >19;[2]c'     : 'DA2 Response: VT340, Pv=%s, keyboard type=%s',
+    '< CSI >19;[2]c'     : 'DA2 Response: VT340, Pv=%s, keyboard type=%s',
+    '< CSI >24;[2]c'     : 'DA2 Response: VT320, Pv=%s, keyboard type=%s',
+    '< CSI >32;[2]c'     : 'DA2 Response: VT382, Pv=%s, keyboard type=%s',
     '< CSI >32;100;2c'   : 'DA2 Response: VT382 (could be TeraTerm)',
-    '< CSI >41;[2]c'     : 'DA2 Response: VT420, Pv=%d, keyboard type=%d',
+    '< CSI >41;[2]c'     : 'DA2 Response: VT420, Pv=%s, keyboard type=%s',
     '< CSI >41;280;0c'   : 'DA2 Response: VT420 (could be xterm patch#280)',
     '< CSI >41;281;0c'   : 'DA2 Response: VT420 (could be xterm patch#281)',
     '< CSI >41;282;0c'   : 'DA2 Response: VT420 (could be xterm patch#282)',
@@ -154,20 +154,20 @@ _SEQDB = {
     '< CSI >41;290;0c'   : 'DA2 Response: VT420 (could be xterm patch#290)',
     '< CSI >41;291;0c'   : 'DA2 Response: VT420 (could be xterm patch#291)',
     '< CSI >41;292;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
-    '< CSI >61;[2]c'     : 'DA2 Response: VT510, Pv=%d, keyboard type=%d',
-    '< CSI >64;[2]c'     : 'DA2 Response: VT520, Pv=%d, keyboard type=%d',
-    '< CSI >65;[2]c'     : 'DA2 Response: VT525, Pv=%d, keyboard type=%d',
+    '< CSI >61;[2]c'     : 'DA2 Response: VT510, Pv=%s, keyboard type=%s',
+    '< CSI >64;[2]c'     : 'DA2 Response: VT520, Pv=%s, keyboard type=%s',
+    '< CSI >65;[2]c'     : 'DA2 Response: VT525, Pv=%s, keyboard type=%s',
     '< CSI >65;100;1c'   : 'DA1 Response: VT500 family (could be RLogin)',
-    '< CSI >77;[2]c'     : 'DA2 Response: could be MinTTY, Pv=%d, keyboard type=%d',
-    '< CSI >77;[1];c'    : 'DA2 Response: could be MinTTY, Pv=%d',
+    '< CSI >77;[2]c'     : 'DA2 Response: could be MinTTY, Pv=%s, keyboard type=%s',
+    '< CSI >77;[1];c'    : 'DA2 Response: could be MinTTY, Pv=%s',
     '< CSI >77;10003;c'  : 'DA2 Response: could be MinTTY 1.0.3',
     '< CSI >77;10101;c'  : 'DA2 Response: could be MinTTY 1.1.1',
     '< CSI >77;10102;c'  : 'DA2 Response: could be MinTTY 1.1.2',
     '< CSI >77;10103;c'  : 'DA2 Response: could be MinTTY 1.1.3',
-    '< CSI >82;[2]c'     : 'DA2 Response: could be mrxvt, Pv=%d, keyboard type=%d',
+    '< CSI >82;[2]c'     : 'DA2 Response: could be mrxvt, Pv=%s, keyboard type=%s',
     '< CSI >82;20710;0c' : 'DA2 Response: could be rxvt/ck',
     '< CSI >82;0.5.4;0c' : 'DA2 Response: could be mrxvt 0.5.4',
-    '< CSI >83;[2]c'     : 'DA2 Response: could be GNU Screen, Pv=%d, keyboard type=%d',
+    '< CSI >83;[2]c'     : 'DA2 Response: could be GNU Screen, Pv=%s, keyboard type=%s',
     '< CSI >83;40000;0c' : 'DA2 Response: could be GNU Screen 4.0.0',
     '< CSI >83;40001;0c' : 'DA2 Response: could be GNU Screen 4.0.1',
     '< CSI >83;40002;0c' : 'DA2 Response: could be GNU Screen 4.0.2',
@@ -176,10 +176,10 @@ _SEQDB = {
     '< CSI >85;95;c'     : 'DA2 Response: could be rxvt-unicode',
     '< CSI 1t'           : 'CSI 11 t Response: window is open',
     '< CSI 2t'           : 'CSI 11 t Response: window is iconified',
-    '< CSI 3;[2]t'       : 'CSI 13 t Response: window position (x, y) is (%d, %d)',
-    '< CSI 4;[2]t'       : 'CSI 14 t Response: window size (height, width) in pixels is (%d, %d)',
-    '< CSI 8;[2]t'       : 'CSI 18 t Response: text area size (height, width) in characters is (%d, %d)',
-    '< CSI 9;[2]t'       : 'CSI 19 t Response: screen size (height, width) in characters is (%d, %d)',
+    '< CSI 3;[2]t'       : 'CSI 13 t Response: window position (x, y) is (%s, %s)',
+    '< CSI 4;[2]t'       : 'CSI 14 t Response: window size (height, width) in pixels is (%s, %s)',
+    '< CSI 8;[2]t'       : 'CSI 18 t Response: text area size (height, width) in characters is (%s, %s)',
+    '< CSI 9;[2]t'       : 'CSI 19 t Response: screen size (height, width) in characters is (%s, %s)',
     '< ESC ]L<ST>'       : 'OSC L / CSI 20 t Response: report icon label',
     '< ESC ]l<ST>'       : 'OSC l / CSI 21 t Response: report title',
     '< ESC O P'          : 'F1 key (xterm)',
@@ -243,15 +243,34 @@ _SEQDB = {
     '> ESC ]2<ST>'       : 'OSC 2 / set window title',
     '> ESC ]4<ST>'       : 'OSC 4 / get or set color palette',
     '> ESC ]9<ST>'       : 'OSC 9 / Growl integration (iTerm2)',
-    '> ESC ]10<ST>'      : 'OSC 10 / get or set foreground color',
-    '> ESC ]11<ST>'      : 'OSC 11 / get or set background color',
-    '> ESC ]12<ST>'      : 'OSC 12 / get or set cursor color',
-    '> ESC ]13<ST>'      : 'OSC 13 / get or set mouse foreground color',
-    '> ESC ]14<ST>'      : 'OSC 13 / get or set mouse background color',
+    '> ESC ]10<ST>'      : 'OSC 10 / set foreground color',
+    '> ESC ]10;?<ST>'    : 'OSC 10 / get foreground color',
+    '> ESC ]11<ST>'      : 'OSC 11 / set background color',
+    '> ESC ]11;?<ST>'    : 'OSC 11 / get background color',
+    '> ESC ]12<ST>'      : 'OSC 12 / set cursor color',
+    '> ESC ]12;?<ST>'    : 'OSC 12 / get cursor color',
+    '> ESC ]13<ST>'      : 'OSC 13 / set mouse foreground color',
+    '> ESC ]13;?<ST>'    : 'OSC 13 / get mouse foreground color',
+    '> ESC ]14<ST>'      : 'OSC 14 / set mouse background color',
+    '> ESC ]14;?<ST>'    : 'OSC 14 / get mouse background color',
+    '> ESC ]15<ST>'      : 'OSC 15 / set tektronix foreground color',
+    '> ESC ]15;?<ST>'    : 'OSC 15 / get tektronix foreground color',
+    '> ESC ]16<ST>'      : 'OSC 16 / set tektronix background color',
+    '> ESC ]16;?<ST>'    : 'OSC 16 / get tektronix background color',
+    '> ESC ]17<ST>'      : 'OSC 17 / set highlight background color',
+    '> ESC ]17;?<ST>'    : 'OSC 17 / get highlight background color',
+    '> ESC ]46<ST>'      : 'OSC 46 / change log file',
+    '> ESC ]50<ST>'      : 'OSC 50 / set font(xterm), set property(Konsole), execute various commands(iTerm2)',
     '> ESC ]51<ST>'      : 'OSC 51 / reserved for Emacs',
     '> ESC ]52;i<ST>'    : 'OSC 52 / term+-edit-insert (term+)',
     '> ESC ]52;h<ST>'    : 'OSC 52 / term+-shell-history (term+)',
     '> ESC ]52<ST>'      : 'OSC 52 - PASTE64 / base64 clipboard read/write operation (xterm)',
+    '> ESC ]104<ST>'     : 'OSC 104 / reset specified color number',
+    '> ESC ]104<ST>'     : 'OSC 104 / reset specified special color number',
+    '> ESC ]110<ST>'     : 'OSC 110 / reset VT100 text foreground color',
+    '> ESC ]111<ST>'     : 'OSC 111 / reset VT100 text background color',
+    '> ESC ]112<ST>'     : 'OSC 112 / reset cursor color',
+    '> ESC ]113<ST>'     : 'OSC 111 / reset VT100 text background color',
     '> ESC ]5379<ST>'    : 'OSC 5379 / exec command or set (mlterm)',
     '> ESC ]5380<ST>'    : 'OSC 5380 / get pty (mlterm)',
     '> ESC ]5381<ST>'    : 'OSC 5381 / get GUI menu (mlterm)',
@@ -462,8 +481,8 @@ _SEQDB = {
     '> CSI ?1047h'       : 'DECSET 1047 / use alternate screen buffer, clearing screen first if in the main screen',
     '> CSI ?1049h'       : 'DECSET 1049 / save cursor as in DECSC and use alternate screen buffer',
     '> CSI ?2004h'       : 'DECSET 2004 / enable bracketed paste mode',
-    '> CSI ?7700h'       : 'DECSET 7700 / enable ambiguous reporting (MinTTY)',
-    '> CSI ?7727h'       : 'DECSET 7727 / application escape keycode mode (MinTTY)',
+    '> CSI ?7700h'       : 'DECSET 7700 / enable ambiguous reporting (MinTTY/tanasinn)',
+    '> CSI ?7727h'       : 'DECSET 7727 / application escape keycode mode (MinTTY/TeraTerm/RLogin/mlterm/tanasinn)',
     '> CSI ?7728h'       : 'DECSET 7728 / treat ^\ as normal escape keycode (MinTTY)',
     '> CSI ?7766h'       : 'DECSET 7766 / show scroll bar (MinTTY)',
     '> CSI i'            : 'MC',
@@ -606,7 +625,7 @@ _SEQDB = {
     '> CSI [0]s'         : 'Save cursor (ANSI.SYS)',
     '> CSI [0]u'         : 'Restore cursor (ANSI.SYS)',
     '> CSI t'            : 'DECSLPP or Window Manipulation (dtterm)',
-    '> CSI [1]t'         : 'DECSLPP / Resize to %d lines',
+    '> CSI [1]t'         : 'DECSLPP / Resize to %s lines',
     '> CSI 1t'           : 'Window Manipulation (dtterm) 1: de-iconify window',
     '> CSI 2t'           : 'Window Manipulation (dtterm) 2: iconify window',
     '> CSI 3;[2]t'       : 'Window Manipulation (dtterm) 3: move window (%s, %s)',
@@ -635,17 +654,17 @@ _SEQDB = {
     '> CSI 23;1t'        : 'Window Manipulation (dtterm) 23: restore icon title on stack',
     '> CSI 23;2t'        : 'Window Manipulation (dtterm) 23: restore window title on stack',
     '> CSI $t'           : 'DECRARA / reverse attributes in rectangular area',
-    '> CSI [5]$t'        : 'DECRARA / reverse attributes in rectangular area - top=%d, left=%d, bottom=%d, right=%d, attribute=%d',
+    '> CSI [5]$t'        : 'DECRARA / reverse attributes in rectangular area - top=%s, left=%s, bottom=%s, right=%s, attribute=%s',
     '> CSI >t'           : 'Title Mode - Set (xterm)',
     '> CSI >0t'          : 'Title Mode - Set (xterm) 0: Set window/icon labels using hexadecimal',
     '> CSI >1t'          : 'Title Mode - Set (xterm) 1: Query window/icon labels using hexadecimal',
     '> CSI >2t'          : 'Title Mode - Set (xterm) 2: Set window/icon labels using UTF-8',
     '> CSI >3t'          : 'Title Mode - Set (xterm) 3: Query window/icon labels using UTF-8',
     '> CSI <SP>t'        : 'DECSWBV / set warning bell volume',
-    '> CSI [1]<SP>t'     : 'DECSWBV / set warning bell volume to %d',
+    '> CSI [1]<SP>t'     : 'DECSWBV / set warning bell volume to %s',
     '> CSI u'            : 'Restore cursor (ANSI.SYS)',
     '> CSI <SP>u'        : 'DECSMBV / set margin bell volume',
-    '> CSI [1]<SP>u'     : 'DECSMBV / set margin bell volume to %d',
+    '> CSI [1]<SP>u'     : 'DECSMBV / set margin bell volume to %s',
     '> CSI $v'           : 'DECCRA / copy rectangular area',
     '> CSI \'w'          : 'DECEFR / enable filter rectangle',
     '> CSI x'            : 'DECRECTPARM / request terminal parameters',
@@ -654,7 +673,7 @@ _SEQDB = {
     '> CSI $x'           : 'DECFRA / fill rectangular area',
     '> CSI \'z'          : 'DECELR / enable locator reporting ',
     '> CSI $z'           : 'DECERA / erase rectangular area',
-    '> CSI [4]$z'        : 'DECErA / erase rectangular area - top=%d, left=%d, bottom=%d, right=%d',
+    '> CSI [4]$z'        : 'DECErA / erase rectangular area - top=%s, left=%s, bottom=%s, right=%s',
 }
 
 _DEFAULT_CONF = """
