@@ -57,21 +57,23 @@ class SwitchOnOffTrait():
 class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
 
     _io_mode = None
+    _xterm_mouse_buffer = None 
 
-    def __init__(self, output_file, termenc, use_header):
+    def __init__(self, output_file, termenc, controller):
         self.__super = super(TraceHandler, self)
         if isinstance(output_file, str):
             output_file = open(output_file, "w")
         self.__log = codecs.getwriter(termenc)(StringIO())
         self.__output = output_file
         self.__bufferring = False 
+        self._controller = controller
         self._io_mode = IOMode()
 
     ''' Switch Input/Output prompt state '''
 
     def set_output(self):
         if self.is_disabled():
-            return False
+            return
         if self._io_mode.is_input():
             if self.__bufferring:
                 self.__log.write("\n")
@@ -80,7 +82,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
 
     def set_input(self):
         if self.is_disabled():
-            return False
+            return
         if self._io_mode.is_output():
             if self.__bufferring:
                 self.__log.write("\n")
@@ -90,68 +92,133 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
     ''' Override Interface tff.EventObserver '''
 
     def handle_esc(self, context, intermediate, final):
+        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+            seq = [ 0x1b, 0x5b, 0x4d ] + self._xterm_mouse_buffer
+            self._xterm_mouse_buffer = None 
+            self.handle_invalid(context, seq)
+        prompt = self._io_mode.get_prompt()
+        formatted = esc.format(intermediate,
+                               final,
+                               self._io_mode.is_input(),
+                               self,
+                               self._controller)
+        if not formatted:
+            return True
         if self.is_disabled():
             return False
         if self.__bufferring:
             self.__log.write("\n")
             self.__bufferring = False
-        prompt = self._io_mode.get_prompt()
-        formatted = esc.format(intermediate, final, self._io_mode.is_input())
         self.__log.write(u"%s  %s\x1b[m\n" % (prompt, formatted))
         return False # not handled
 
     def handle_csi(self, context, parameter, intermediate, final):
+        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+            seq = [ 0x1b, 0x5b, 0x4d ] + self._xterm_mouse_buffer
+            self._xterm_mouse_buffer = None 
+            self.handle_invalid(context, seq)
+        prompt = self._io_mode.get_prompt()
+        formatted = csi.format(parameter,
+                               intermediate,
+                               final,
+                               self._io_mode.is_input(),
+                               self,
+                               self._controller)
+        if final == 0x4d:
+            if len(parameter) == 0 and len(intermediate) == 0:
+                self._xterm_mouse_buffer = []
+                return False
+        if not formatted:
+            return True
         if self.is_disabled():
             return False
         if self.__bufferring:
             self.__log.write("\n")
             self.__bufferring = False
-        prompt = self._io_mode.get_prompt()
-        formatted = csi.format(parameter, intermediate, final, self._io_mode.is_input())
         self.__log.write(u"%s  %s\x1b[m\n" % (prompt, formatted))
         return False # not handled
 
     def handle_ss2(self, context, final):
+        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+            seq = [ 0x1b, 0x5b, 0x4d ] + self._xterm_mouse_buffer
+            self._xterm_mouse_buffer = None 
+            self.handle_invalid(context, seq)
+        prompt = self._io_mode.get_prompt()
+        formatted = ss2.format(final,
+                               self._io_mode.is_input(),
+                               self,
+                               self._controller)
+        if not formatted:
+            return True
         if self.is_disabled():
             return False
         if self.__bufferring:
             self.__log.write("\n")
             self.__bufferring = False
-        prompt = self._io_mode.get_prompt()
-        formatted = ss2.format(final, self._io_mode.is_input())
         self.__log.write(u"%s  %s\x1b[m\n" % (prompt, formatted))
         return False # not handled
 
     def handle_ss3(self, context, final):
+        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+            seq = [ 0x1b, 0x5b, 0x4d ] + self._xterm_mouse_buffer
+            self._xterm_mouse_buffer = None 
+            self.handle_invalid(context, seq)
+        prompt = self._io_mode.get_prompt()
+        formatted = ss3.format(final,
+                               self._io_mode.is_input(),
+                               self,
+                               self._controller)
+        if not formatted:
+            return True
         if self.is_disabled():
             return False
         if self.__bufferring:
             self.__log.write("\n")
             self.__bufferring = False
-        prompt = self._io_mode.get_prompt()
-        formatted = ss3.format(final, self._io_mode.is_input())
         self.__log.write(u"%s  %s\x1b[m\n" % (prompt, formatted))
         return False # not handled
 
     def handle_control_string(self, context, prefix, value):
+        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+            seq = [ 0x1b, 0x5b, 0x4d ] + self._xterm_mouse_buffer
+            self._xterm_mouse_buffer = None 
+            self.handle_invalid(context, seq)
         if self.is_disabled():
             return False
         if self.__bufferring:
             self.__log.write("\n")
             self.__bufferring = False
         prompt = self._io_mode.get_prompt()
-        formatted = cstr.format(prefix, value, self._io_mode.is_input())
+        formatted = cstr.format(prefix,
+                                value,
+                                self._io_mode.is_input(),
+                                self,
+                                self._controller)
+        if not formatted:
+            return True
         self.__log.write(u"%s  %s\x1b[m\n" % (prompt, formatted))
         return False # not handled
 
     def handle_char(self, context, c):
+        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+            self._xterm_mouse_buffer.append(c) 
+            if len(self._xterm_mouse_buffer) == 3:
+                seq = self._xterm_mouse_buffer
+                self._xterm_mouse_buffer = None
+                self.handle_xterm_mouse(context, seq)
+            return False
+        mnemonic, handled = char.format(c,
+                                        self._io_mode.is_input(),
+                                        self,
+                                        self._controller)
+        if not mnemonic:
+            return True
         if self.is_disabled():
             return False
         if not self.__bufferring:
             self.__bufferring = True
             prompt = self._io_mode.get_prompt()
             self.__log.write(u"%s  " % prompt)
-        mnemonic, handled = char.format(c, self._io_mode.is_input())
         if handled:
             self.__bufferring = False
             self.__log.write(mnemonic)
@@ -161,6 +228,10 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         return False # not handled
 
     def handle_invalid(self, context, seq):
+        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+            seq = [ 0x1b, 0x5b, 0x4d ] + self._xterm_mouse_buffer
+            self._xterm_mouse_buffer = None 
+            self.handle_invalid(context, seq)
         if self.is_disabled():
             return False
         if self.__bufferring:
@@ -170,6 +241,18 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         value = str([hex(c) for c in seq])
         self.__log.write("%s  \x1b[33;41m%s\x1b[0m\n" % (prompt, value))
 
+    def handle_xterm_mouse(self, context, seq):
+        if self.is_disabled():
+            return False
+        if self.__bufferring:
+            self.__log.write("\n")
+            self.__bufferring = False
+        prompt = self._io_mode.get_prompt()
+        info = (seq[0] - 32, seq[1] - 32, seq[2] - 32)
+        value = "xterm normal mouse: button=%d, row=%d, col=%d" % info
+        self.__log.write("%s   \x1b[0;1;31mCSI \x1b[35mM \x1b[m%c %c %c \x1b[32;41m%s\x1b[0m\n" % (prompt, seq[0], seq[1], seq[2], value))
+        pass
+
     def handle_resize(self, context, row, col):
         if self.is_disabled():
             return False
